pub struct TsPayload { /* private fields */ }Expand description
Payload of a transport stream object.
Implementations
Sourceimpl TsPayload
impl TsPayload
Sourcepub fn from_bytes(
pusi: bool,
continuity_counter: u8,
payload_data: &[u8],
) -> TsPayload
pub fn from_bytes( pusi: bool, continuity_counter: u8, payload_data: &[u8], ) -> TsPayload
Parse the payload data and pusi from the raw payload bytes.
Sourcepub fn continuity_counter(&self) -> u8
pub fn continuity_counter(&self) -> u8
Return the continuity counter of this payload.
Sourcepub fn is_start(&self) -> bool
pub fn is_start(&self) -> bool
Returns if this payload contains the start of a new payload in it’s data.
Sourcepub fn get_payload_data(self) -> TsPayloadData
pub fn get_payload_data(self) -> TsPayloadData
Returns the current payload data. This is the data before the start index, if one exists.