TsReader

Struct TsReader 

pub struct TsReader<T> { /* private fields */ }
Struct used for holding information related to reading the transport stream.

Implementations

Source

impl<T> TsReader<T>

pub fn packets_read(&self) -> &u64

Counter of the number of packets read

Source

impl<T> TsReader<T>
where T: Read + Seek,

pub fn iter_packets(&mut self) -> TsPackets<'_, T>

pub fn iter_payloads(&mut self) -> TsPayloads<'_, T>

pub fn stream_position(&mut self) -> u64

pub fn new(buf_reader: T) -> Result<Self, ErrorKind>

Create a new TSReader instance using the given file.

This function also finds the first SYNC byte, so we can determine the alignment of the transport packets.

Parameters
  • buf_reader: a buffered reader that contains transport stream data.
pub fn next_packet_unchecked(&mut self) -> Option<TsPacket>

Read the next packet from the transport stream file.

This function returns None for any Err in order to prevent the need for .unwrap() calls in more concise code.

Returns

Some(TSPacket) if the next transport stream packet could be parsed from the file. None if the next transport stream packet could not be parsed from the file for any reason. This includes if the entire file has been fully read.

pub fn next_packet(&mut self) -> Result<Option<TsPacket>, ErrorKind>

Read the next packet from the transport stream file.

Returns

Ok(Some(TSPacket)) if the next transport stream packet could be parsed from the file. Ok(None) if there was no issue reading the file and no more TS packets can be read.

pub fn next_payload_unchecked(&mut self) -> Option<Vec<u8>>

Read the next payload from the transport stream file.

This function returns None for any Err in order to prevent the need for .unwrap() calls in more concise code.

Returns

Some(TSPayload) if the next transport stream packet could be parsed from the file. None if the next transport stream payload could not be parsed from the file for any reason. This includes if the entire file has been fully read.

pub fn next_payload(&mut self) -> Result<Option<Vec<u8>>, ErrorKind>

Read the next full payload from the file.

This function parses through all transport stream packets, stores them in a buffer and concatenates their payloads together once a payload has been complete.

NOTE: I make the assumption that all packets containing KLV data are PSI packets and therefore the first byte of the payload indicates when the start of the new payload is.

NOTE: By looking at the source I determined that mpeg2ts classifies the payload type by the PID and only checks against known, reserved PIDs, while all other are instantiated as TransportPayload::Raw(Bytes). Because all PIDs for the data we are looking for are going to be non-constant, we can just discard all variants besides TransportPayload::Raw.

TODO: A performance enhancment that could be made is to look for the first TransportPayload::PAT payload and use that (and the TransportPayload::PMT that it points to) to determine what PIDs are PSI and which are PET. We can then disregard all PET streams instead of naively treating them as PSI streams and trying to find a KLV value in it.

pub fn sync_byte_alignment(&self) -> u64

Return the alignment of the SYNC bytes in this reader.

pub fn add_tracked_pid(&mut self, pid: u16)

Add a PID to the tracking list.

Only tracked PIDs are returned when running methods that gather packets or payloads. If no PIDs are set to be tracked, then all PIDs are tracked.

pub fn remove_tracked_pid(&mut self, pid: u16)

Remove this PID from being tracked.

Only tracked PIDs are returned when running methods that gather packets or payloads. If no PIDs are set to be tracked, then all PIDs are tracked.