Crate ts_analyzer
source ·Expand description
This crate is used to read the payload data from a given transport stream.
Modules
- Holds all the information regarding a given packet from the transport stream.
- ts-analyzer
This crate is used to read the payload data from a given transport stream.